.. ya360 documentation master file, created by
   sphinx-quickstart on Wed Jul 13 18:26:45 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. meta::
   :yandex-verification: 298d3ebcf3412964

Документация ya360
==================
**ya360** - Утилита командной строки для Yandex 360

   | *Для фанатов автоматизации UNIX/Linux - style или тех, кто устал курлить*

Автоматизируйте процессы администрирования Yandex 360 как вам удобно и откуда угодно, везде, где есть доступ к командной строке

   | *Автоматизируйте и админте. Админте и автоматизируйте. Да прибудет с вами CLI!*

.. toctree::
   :maxdepth: 2
   :caption:  Содержание

   befo
   cmd

.. toctree::
   :maxdepth: 6
   :caption:  Экспериментальный

   routing

.. toctree::
   :maxdepth: 6
   :caption:  Лицензирование

   lic
